@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -660,11 +660,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (p=command; *p != '\0'; p++)
           if (isspace((int) (unsigned char) *p) != 0)
             break;
-        value=AcquireString(p);
+        value=ConstantString(p);
         (void) SubstituteString(&value,"(","");
         (void) SubstituteString(&value,")","");
         (void) StripString(value);
-        (void) SetImageProperty(image,property,value);
+        if (*value != '\0')
+          (void) SetImageProperty(image,property,value);
         value=DestroyString(value);
         continue;
       }
@@ -1586,6 +1587,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
   size_t
     bit,
     byte,
+    imageListLength,
     length,
     page,
     text_size;
@@ -1618,6 +1620,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     compression=image_info->compression;
   page=1;
   scene=0;
+  imageListLength=GetImageListLength(image);
   do
   {
     /*
@@ -2269,8 +2272,13 @@ RestoreMSCWarning
                   p++;
                 }
                 q=PopHexPixel(hex_digits,(size_t) index,q);
-                q=PopHexPixel(hex_digits,(size_t)
-                  MagickMin(length,0xff),q);
+                q=PopHexPixel(hex_digits,(size_t) MagickMin(length,0xff),q);
+                if ((q-pixels+6) >= 80)
+                  {
+                    *q++='\n';
+                    (void) WriteBlob(image,q-pixels,pixels);
+                    q=pixels;
+                  }
                 if (image->previous == (Image *) NULL)
                   {
                     status=SetImageProgress(image,SaveImageTag,
@@ -2336,8 +2344,7 @@ RestoreMSCWarning
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,
-      GetImageListLength(image));
+    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
